@@ -1,6 +1,7 @@
-
 import logging
 
+logging.basicConfig(level=100) # avoid logging messages from other loggers
+
 import atheist.gvar as gvar
 
 DATEFORMAT = '%d/%m/%y %H:%M:%S'
@@ -16,10 +17,13 @@ def create_basic_handler():
     console.setFormatter(formatter)
     return console
 
-if gvar.Log is None:
-    gvar.Log = logging.getLogger('atheist')
-    if not gvar.Log.handlers:
-        gvar.Log.addHandler(create_basic_handler())
+def create_logger(name):
+    retval = logging.getLogger(name)
+    if not retval.handlers:
+        retval.addHandler(create_basic_handler())
+        retval.propagate = 0
+        retval.setLevel(logging.WARNING)
+    return retval
 
-        gvar.Log.propagate = 0
-        gvar.Log.setLevel(logging.WARNING)
+if gvar.Log is None:
+    gvar.Log = create_logger('atheist')
