@@ -2,25 +2,26 @@ import os
 import imp, inspect
 
 import atheist
-from atheist.gvar import Log
+import atheist.log
+
+log = atheist.log.create_logger("PluginManager")
+
 
 class Loader(object):
     def __init__(self, dname):
         self.plugins = []
         for m in self.load_modules(dname):
 
-            Log.debug("PluginManager: Loading module '%s'" % m.__file__)
+            log.debug("PluginManager: Loading module '%s'" % m.__file__)
 
             klases = [x[1] for x in inspect.getmembers(m, inspect.isclass)]
             if not klases:
                 continue
 
-            plugins = [x for x in klases
-                       if issubclass(x, atheist.Task) or
-                       issubclass(x, atheist.Condition)]
+            plugins = [x for x in klases if issubclass(x, atheist.Plugin)]
 
             self.plugins.extend(plugins)
-            Log.debug("PluginManager: %s" % [x.__name__ for x in plugins])
+            log.debug("PluginManager: %s" % [x.__name__ for x in plugins])
 
 
     @staticmethod
@@ -34,7 +35,7 @@ class Loader(object):
 
         for f in files:
             fp, fpath, desc =  imp.find_module(f, [dname])
-#            Log.debug("Module: %s %s" % (fpath, desc))
+            log.debug("Module: %s %s" % (fpath, desc))
             try:
                 modules.append(imp.load_module(f, fp, fpath, desc))
             finally:
