@@ -7,7 +7,7 @@ import atheist
 from atheist.const import *
 
 
-class CompositeCondition(atheist.ConditionDecorator):
+class CompositeCondition(atheist.ConditionDecorator, atheist.Plugin):
     def __init__(self, oper, *conds):
         assert callable(oper)
         self.oper = oper
@@ -16,6 +16,6 @@ class CompositeCondition(atheist.ConditionDecorator):
     def run(self):
         return self.oper([c.run() for c in self.conds])
 
-class Or(CompositeCondition):
+class Or(CompositeCondition, atheist.Plugin):
     def __init__(self, *conds):
         CompositeCondition.__init__(self, any, *conds)
