@@ -7,7 +7,7 @@ import atheist
 import os
 import commands
 
-class DebPkgInstalled(atheist.Condition):
+class DebPkgInstalled(atheist.Condition, atheist.Plugin):
     """Check the given debian package is installed. Optionally you
     may ask for a minimum version"""
 
@@ -30,14 +30,20 @@ class DebPkgInstalled(atheist.Condition):
                         installed, self.version))
         return retval
 
+    def __eq__(self, other):
+        return atheist.Condition.__eq__(self, other) \
+            and self.package == other.package \
+            and self.version == other.version
+
     def basic_info(self):
         return "'%s'" % self.package
 
 
-class DebPkgBuild(atheist.Subprocess):
+
+class DebPkgBuild(atheist.Subprocess, atheist.Plugin):
     """Test a Debian package building from 'debian' directory by using pbuilder"""
 
-    def __init__(self, debian_dir, timeout = 3600):
+    def __init__(self, debian_dir, timeout=3600):
         assert isinstance(debian_dir, str)
         buildir = '/tmp/'
         atheist.Subprocess.__init__(self, "pdebuild --buildresult %s" % buildir, timeout=timeout)
@@ -87,7 +93,7 @@ class DebPkgBuild(atheist.Subprocess):
         return os.path.abspath(self.cwd + "/debian")
 
 
-class DebPkgInstall(atheist.Subprocess):
+class DebPkgInstall(atheist.Subprocess, atheist.Plugin):
     """Test a Debian package installation using piuparts"""
 
     def __init__(self, deb_files,
