@@ -1,29 +1,29 @@
-import sys
 # -*- coding:utf-8 -*-
 
+import sys
+import doctest
 import atheist
 
-
-class DocTest(atheist.Task):
-
+class DocTest(atheist.Plugin, atheist.Task):
+    acro = 'DocT'
     allows = ['cwd', 'delay', 'desc', 'must_fail', 'template', 'tid']
 
-    def __init__(self, module, **kargs):
-        self.module = module
+    def __init__(self, module_name, **kargs):
+        self.module_name = module_name
         self.check = True
 
         atheist.Task.__init__(self, **kargs)
+        self.wrap_outs = True
 
 
     def exec_task(self):
         self.log.debug("runing doctest")
-        import doctest
 
         if self.cwd:
             sys.path.append(self.cwd)
 
         try:
-            module = __import__(self.module, fromlist=self.module.split('.')[-1])
+            module = __import__(self.module_name, fromlist=self.module_name.split('.')[-1])
             self.log.debug("%s" % module)
             self.result = (doctest.testmod(module)[0] == 0)
             del module
@@ -32,4 +32,6 @@ class DocTest(atheist.Task):
             atheist.Log.warning(e)
             self.result = atheist.ERROR
 
-        del doctest
+
+    def str_param(self):
+        return self.module_name
