@@ -4,7 +4,7 @@ import time
 
 import atheist
 
-class TimeLessThan(atheist.Condition):
+class TimeLessThan(atheist.Condition, atheist.Plugin):
     """ Check the execution time is less than the specified (in seconds) """
 
     def __init__(self, t):
@@ -14,9 +14,9 @@ class TimeLessThan(atheist.Condition):
         self.tini = None
         self.tend = None
 
-    def before(self, task):
+    def before(self, task, condlist, pos):
         self.tini = time.time()
-        atheist.Condition.before(self, task)
+        atheist.Condition.before(self, task, condlist, pos)
 
     def after(self):
         self.tend = time.time()
@@ -26,3 +26,7 @@ class TimeLessThan(atheist.Condition):
         assert self.tend is not None, "Internal error"
 
         return self.tend - self.tini <= self.max
+
+    def __eq__(self, other):
+        return atheist.Condition.__eq__(self, other) and \
+            self.max == other.max
