@@ -3,8 +3,9 @@
 import atheist
 
 
-class TaskFinished(atheist.Condition):
+class TaskFinished(atheist.Condition, atheist.Plugin):
     """Check if some tasks has been executed or not (pending of execution)"""
+    #FIXME: TaskFinished is the same of Not(TaskRunning)???
 
     def __init__(self, *tasks):
         for t in tasks:
@@ -16,25 +17,36 @@ class TaskFinished(atheist.Condition):
         return all([t.result in (atheist.FAIL, atheist.OK)
                     for t in self.the_tasks])
 
+    def __eq__(self, other):
+        return atheist.Condition.__eq__(self, other) and \
+            set(self.the_tasks) == set(other.the_tasks)
 
-class TaskRunning(atheist.Condition):
-    """Check whether some tasks is running or not"""
+    def basic_info(self):
+        return "%s" %  [t.name for t in self.the_tasks]
+
+
+class TaskRunning(atheist.Condition, atheist.Plugin):
+    """Check whether some tasks are running"""
+    # FIXME: solo sirve para Subprocess
 
     def __init__(self, *tasks):
-        for t in tasks:
-            assert isinstance(t, atheist.Task)
         self.the_tasks = list(tasks)[:]
         atheist.Condition.__init__(self)
 
     def run(self):
-        return all([(t.ps is not None) and (t.ps.poll() is None)
-                    for t in self.the_tasks])
+#        return all([(t.ps is not None) and (t.ps.poll() is None)
+#                    for t in self.the_tasks])
+        return all(t.is_running() for t in self.the_tasks)
+
+    def __eq__(self, other):
+        return atheist.Condition.__eq__(self, other) and \
+            set(self.the_tasks) == self.other(the_tasks)
 
     def basic_info(self):
         return "%s" % [t.name for t in self.the_tasks]
 
 
-class TaskTerminator(atheist.Task):
+class TaskTerminator(atheist.Task, atheist.Plugin):
     """A special task to kill and ensure the termination of other tasks."""
 
     def __init__(self, *tasks, **kargs):
@@ -49,7 +61,7 @@ class TaskTerminator(atheist.Task):
 
         # FIXME: aún no está fijado el indx
         self.desc = "Terminates %s" % \
-            ', '.join(['T'+str(x.indx) for x in self.tasks])
+            ', '.join([x.name for x in self.tasks])
 
         for t in self.tasks:
             self.post += atheist.Poll(atheist.Not(TaskRunning(t)))
@@ -58,8 +70,7 @@ class TaskTerminator(atheist.Task):
         for t in self.tasks:
             self.log.debug("terminates %s sending signal %s" % \
                                (t.name, t.signal))
-            t.kill()
+            t.terminate()
 
     def str_param(self):
         return [x.name for x in self.tasks]
-
