@@ -4,7 +4,6 @@
 #
 # Copyright (C) 2010 Oscar Aceña
 #
-#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 3 of the License, or
@@ -23,20 +22,20 @@ import sys, unittest, inspect
 
 import atheist
 
-class UnitTask(atheist.Task):
+
+class UnitTask(atheist.Task, atheist.Plugin):
     acro = 'Unit'
-    allows = ['check', 'cwd', 'delay', 'desc', 'expected', 'must_fail']
+    allows = ['check', 'delay', 'desc', 'expected', 'must_fail']
 
     def __init__(self, utest, name, **kargs):
         assert callable(utest)
         self.utest = utest
+        self._name = name
 
         atheist.Task.__init__(self, **kargs)  #  name[len("test"):]
-
+        self.wrap_outs = True
 
     def exec_task(self):
-        sys.stdout = self.outwrap
-        sys.stderr = self.errwrap
 
         try:
             tr = unittest.TestResult()
@@ -49,20 +48,23 @@ class UnitTask(atheist.Task):
             # and errors are caused by incorrect code
             elif tr.errors:
                 sys.stderr.write(tr.errors[0][1])
-                self.result = atheist.FAIL
+                self.result = atheist.ERROR
 
             elif tr.failures:
                 sys.stderr.write(tr.failures[0][1])
-                self.result = atheist.ERROR
+                self.result = atheist.FAIL
 
-        finally:
-            sys.stdout = sys.__stdout__
-            sys.stderr = sys.__stderr__
+        except Exception, e:
+            self.log.error(e)
+            self.result = atheist.FAIL
+
+    def str_param(self):
+        return self._name
 
 
 #FIXME: generar automáticamente a partir de ficheros que contienen unittest.TestCase
 # como hace trial, py.test o python2.7. Quizá se podría usar trial.
-class UnitTestCase(atheist.CompositeTask):
+class UnitTestCase(atheist.CompositeTask, atheist.Plugin):
     acro = 'UCas'
 
     def __init__(self, klass):
@@ -83,4 +85,3 @@ class UnitTestCase(atheist.CompositeTask):
 
         atheist.CompositeTask.__init__(self, all, *children)
         self.desc = "%s" % (klass.__name__)
-#                                ', '.join([x[0] for x in methods]))
