@@ -7,7 +7,8 @@ PURPLE = ESC+'[95m'
 GREEN = ESC+'[32m'
 
 LIGHT_RED =   ESC+'[1;91m'
-LIGHT_GREEN = ESC+'[7;32m'
+LIGHT_RED_BG =   ESC+'[7;91m'
+LIGHT_GREEN_BG = ESC+'[7;32m'
 
 BOLD =  ESC+'[1m'
 
