@@ -6,7 +6,7 @@
 
 """
 
-from socket import socket
+import socket
 
 def getFreePort(host=""):
     """Get a free port.
@@ -16,7 +16,7 @@ def getFreePort(host=""):
     :returns:  int -- the free port.
 
     """
-    s = socket()
+    s = socket.socket()
     s.bind((host, 0))
     port = s.getsockname()[1]
     s.close()
